# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/cogneed-ks/services/auth_forward_audio.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.cogneed_ks.services import forward_audio_pb2 as cogneed__protos_dot_cogneed__ks_dot_services_dot_forward__audio__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/cogneed-ks/services/auth_forward_audio.proto',
  package='ai.cogneed.cloud.speech.v1',
  syntax='proto3',
  serialized_options=_b('\n\032ai.cogneed.cloud.speech.v1P\001'),
  serialized_pb=_b('\n;cogneed-protos/cogneed-ks/services/auth_forward_audio.proto\x12\x1a\x61i.cogneed.cloud.speech.v1\x1a\x36\x63ogneed-protos/cogneed-ks/services/forward_audio.proto\"h\n\x17\x41uthForwardAudioRequest\x12>\n\x05\x61udio\x18\x01 \x01(\x0b\x32/.ai.cogneed.cloud.speech.v1.ForwardAudioRequest\x12\r\n\x05token\x18\x02 \x01(\t2\x8f\x01\n\x17\x41uthForwardAudioService\x12t\n\x07\x66orward\x12\x33.ai.cogneed.cloud.speech.v1.AuthForwardAudioRequest\x1a\x30.ai.cogneed.cloud.speech.v1.ForwardAudioResponse(\x01\x30\x01\x42\x1e\n\x1a\x61i.cogneed.cloud.speech.v1P\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_cogneed__ks_dot_services_dot_forward__audio__pb2.DESCRIPTOR,])




_AUTHFORWARDAUDIOREQUEST = _descriptor.Descriptor(
  name='AuthForwardAudioRequest',
  full_name='ai.cogneed.cloud.speech.v1.AuthForwardAudioRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='audio', full_name='ai.cogneed.cloud.speech.v1.AuthForwardAudioRequest.audio', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='ai.cogneed.cloud.speech.v1.AuthForwardAudioRequest.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=147,
  serialized_end=251,
)

_AUTHFORWARDAUDIOREQUEST.fields_by_name['audio'].message_type = cogneed__protos_dot_cogneed__ks_dot_services_dot_forward__audio__pb2._FORWARDAUDIOREQUEST
DESCRIPTOR.message_types_by_name['AuthForwardAudioRequest'] = _AUTHFORWARDAUDIOREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AuthForwardAudioRequest = _reflection.GeneratedProtocolMessageType('AuthForwardAudioRequest', (_message.Message,), dict(
  DESCRIPTOR = _AUTHFORWARDAUDIOREQUEST,
  __module__ = 'cogneed_protos.cogneed_ks.services.auth_forward_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.AuthForwardAudioRequest)
  ))
_sym_db.RegisterMessage(AuthForwardAudioRequest)


DESCRIPTOR._options = None

_AUTHFORWARDAUDIOSERVICE = _descriptor.ServiceDescriptor(
  name='AuthForwardAudioService',
  full_name='ai.cogneed.cloud.speech.v1.AuthForwardAudioService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=254,
  serialized_end=397,
  methods=[
  _descriptor.MethodDescriptor(
    name='forward',
    full_name='ai.cogneed.cloud.speech.v1.AuthForwardAudioService.forward',
    index=0,
    containing_service=None,
    input_type=_AUTHFORWARDAUDIOREQUEST,
    output_type=cogneed__protos_dot_cogneed__ks_dot_services_dot_forward__audio__pb2._FORWARDAUDIORESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_AUTHFORWARDAUDIOSERVICE)

DESCRIPTOR.services_by_name['AuthForwardAudioService'] = _AUTHFORWARDAUDIOSERVICE

# @@protoc_insertion_point(module_scope)
