# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/cogneed-waveform/services/waveform_loading.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/cogneed-waveform/services/waveform_loading.proto',
  package='ai.cogneed.cloud.speech.v1',
  syntax='proto3',
  serialized_options=_b('\n\032ai.cogneed.cloud.speech.v1P\001'),
  serialized_pb=_b('\n?cogneed-protos/cogneed-waveform/services/waveform_loading.proto\x12\x1a\x61i.cogneed.cloud.speech.v1\"!\n\x13WaveformLoadRequest\x12\n\n\x02id\x18\x01 \x01(\t\"%\n\x14WaveformLoadResponse\x12\r\n\x05peaks\x18\x01 \x03(\x05\x32\x83\x01\n\x16WaveformLoadingService\x12i\n\x04load\x12/.ai.cogneed.cloud.speech.v1.WaveformLoadRequest\x1a\x30.ai.cogneed.cloud.speech.v1.WaveformLoadResponseB\x1e\n\x1a\x61i.cogneed.cloud.speech.v1P\x01\x62\x06proto3')
)




_WAVEFORMLOADREQUEST = _descriptor.Descriptor(
  name='WaveformLoadRequest',
  full_name='ai.cogneed.cloud.speech.v1.WaveformLoadRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ai.cogneed.cloud.speech.v1.WaveformLoadRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=128,
)


_WAVEFORMLOADRESPONSE = _descriptor.Descriptor(
  name='WaveformLoadResponse',
  full_name='ai.cogneed.cloud.speech.v1.WaveformLoadResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peaks', full_name='ai.cogneed.cloud.speech.v1.WaveformLoadResponse.peaks', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=130,
  serialized_end=167,
)

DESCRIPTOR.message_types_by_name['WaveformLoadRequest'] = _WAVEFORMLOADREQUEST
DESCRIPTOR.message_types_by_name['WaveformLoadResponse'] = _WAVEFORMLOADRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

WaveformLoadRequest = _reflection.GeneratedProtocolMessageType('WaveformLoadRequest', (_message.Message,), dict(
  DESCRIPTOR = _WAVEFORMLOADREQUEST,
  __module__ = 'cogneed_protos.cogneed_waveform.services.waveform_loading_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.WaveformLoadRequest)
  ))
_sym_db.RegisterMessage(WaveformLoadRequest)

WaveformLoadResponse = _reflection.GeneratedProtocolMessageType('WaveformLoadResponse', (_message.Message,), dict(
  DESCRIPTOR = _WAVEFORMLOADRESPONSE,
  __module__ = 'cogneed_protos.cogneed_waveform.services.waveform_loading_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.WaveformLoadResponse)
  ))
_sym_db.RegisterMessage(WaveformLoadResponse)


DESCRIPTOR._options = None

_WAVEFORMLOADINGSERVICE = _descriptor.ServiceDescriptor(
  name='WaveformLoadingService',
  full_name='ai.cogneed.cloud.speech.v1.WaveformLoadingService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=170,
  serialized_end=301,
  methods=[
  _descriptor.MethodDescriptor(
    name='load',
    full_name='ai.cogneed.cloud.speech.v1.WaveformLoadingService.load',
    index=0,
    containing_service=None,
    input_type=_WAVEFORMLOADREQUEST,
    output_type=_WAVEFORMLOADRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_WAVEFORMLOADINGSERVICE)

DESCRIPTOR.services_by_name['WaveformLoadingService'] = _WAVEFORMLOADINGSERVICE

# @@protoc_insertion_point(module_scope)
