# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/cogneed-ks/models/mfcc_audio.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/cogneed-ks/models/mfcc_audio.proto',
  package='ai.cogneed.cloud.speech.v1',
  syntax='proto3',
  serialized_options=_b('\n\032ai.cogneed.cloud.speech.v1P\001'),
  serialized_pb=_b('\n1cogneed-protos/cogneed-ks/models/mfcc_audio.proto\x12\x1a\x61i.cogneed.cloud.speech.v1\"\"\n\nMfccWindow\x12\x14\n\x0c\x63oefficients\x18\x01 \x03(\x01\"D\n\tMfccAudio\x12\x37\n\x07windows\x18\x01 \x03(\x0b\x32&.ai.cogneed.cloud.speech.v1.MfccWindowB\x1e\n\x1a\x61i.cogneed.cloud.speech.v1P\x01\x62\x06proto3')
)




_MFCCWINDOW = _descriptor.Descriptor(
  name='MfccWindow',
  full_name='ai.cogneed.cloud.speech.v1.MfccWindow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='coefficients', full_name='ai.cogneed.cloud.speech.v1.MfccWindow.coefficients', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=115,
)


_MFCCAUDIO = _descriptor.Descriptor(
  name='MfccAudio',
  full_name='ai.cogneed.cloud.speech.v1.MfccAudio',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='windows', full_name='ai.cogneed.cloud.speech.v1.MfccAudio.windows', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=117,
  serialized_end=185,
)

_MFCCAUDIO.fields_by_name['windows'].message_type = _MFCCWINDOW
DESCRIPTOR.message_types_by_name['MfccWindow'] = _MFCCWINDOW
DESCRIPTOR.message_types_by_name['MfccAudio'] = _MFCCAUDIO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MfccWindow = _reflection.GeneratedProtocolMessageType('MfccWindow', (_message.Message,), dict(
  DESCRIPTOR = _MFCCWINDOW,
  __module__ = 'cogneed_protos.cogneed_ks.models.mfcc_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.MfccWindow)
  ))
_sym_db.RegisterMessage(MfccWindow)

MfccAudio = _reflection.GeneratedProtocolMessageType('MfccAudio', (_message.Message,), dict(
  DESCRIPTOR = _MFCCAUDIO,
  __module__ = 'cogneed_protos.cogneed_ks.models.mfcc_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.MfccAudio)
  ))
_sym_db.RegisterMessage(MfccAudio)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
