# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/cogneed-ks/services/stream_audio.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/cogneed-ks/services/stream_audio.proto',
  package='ai.cogneed.cloud.speech.v1',
  syntax='proto3',
  serialized_options=_b('\n\032ai.cogneed.cloud.speech.v1P\001'),
  serialized_pb=_b('\n5cogneed-protos/cogneed-ks/services/stream_audio.proto\x12\x1a\x61i.cogneed.cloud.speech.v1\"\'\n\x16InitAudioStreamRequest\x12\r\n\x05token\x18\x01 \x01(\t\",\n\x17InitAudioStreamResponse\x12\x11\n\tcall_uuid\x18\x01 \x01(\t\"B\n\x12StreamAudioRequest\x12\r\n\x05token\x18\x01 \x01(\t\x12\x0c\n\x04uuid\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\x0c\"%\n\x13StreamAudioResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"4\n\x15\x45ndAudioStreamRequest\x12\r\n\x05token\x18\x01 \x01(\t\x12\x0c\n\x04uuid\x18\x02 \x01(\t2\xe0\x02\n\x12StreamAudioService\x12o\n\x04init\x12\x32.ai.cogneed.cloud.speech.v1.InitAudioStreamRequest\x1a\x33.ai.cogneed.cloud.speech.v1.InitAudioStreamResponse\x12i\n\x06stream\x12..ai.cogneed.cloud.speech.v1.StreamAudioRequest\x1a/.ai.cogneed.cloud.speech.v1.StreamAudioResponse\x12n\n\x08\x66inalize\x12\x31.ai.cogneed.cloud.speech.v1.EndAudioStreamRequest\x1a/.ai.cogneed.cloud.speech.v1.StreamAudioResponseB\x1e\n\x1a\x61i.cogneed.cloud.speech.v1P\x01\x62\x06proto3')
)




_INITAUDIOSTREAMREQUEST = _descriptor.Descriptor(
  name='InitAudioStreamRequest',
  full_name='ai.cogneed.cloud.speech.v1.InitAudioStreamRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='ai.cogneed.cloud.speech.v1.InitAudioStreamRequest.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=85,
  serialized_end=124,
)


_INITAUDIOSTREAMRESPONSE = _descriptor.Descriptor(
  name='InitAudioStreamResponse',
  full_name='ai.cogneed.cloud.speech.v1.InitAudioStreamResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_uuid', full_name='ai.cogneed.cloud.speech.v1.InitAudioStreamResponse.call_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=126,
  serialized_end=170,
)


_STREAMAUDIOREQUEST = _descriptor.Descriptor(
  name='StreamAudioRequest',
  full_name='ai.cogneed.cloud.speech.v1.StreamAudioRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='ai.cogneed.cloud.speech.v1.StreamAudioRequest.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.cloud.speech.v1.StreamAudioRequest.uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.cloud.speech.v1.StreamAudioRequest.content', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=172,
  serialized_end=238,
)


_STREAMAUDIORESPONSE = _descriptor.Descriptor(
  name='StreamAudioResponse',
  full_name='ai.cogneed.cloud.speech.v1.StreamAudioResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ai.cogneed.cloud.speech.v1.StreamAudioResponse.status', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=240,
  serialized_end=277,
)


_ENDAUDIOSTREAMREQUEST = _descriptor.Descriptor(
  name='EndAudioStreamRequest',
  full_name='ai.cogneed.cloud.speech.v1.EndAudioStreamRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='ai.cogneed.cloud.speech.v1.EndAudioStreamRequest.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.cloud.speech.v1.EndAudioStreamRequest.uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=279,
  serialized_end=331,
)

DESCRIPTOR.message_types_by_name['InitAudioStreamRequest'] = _INITAUDIOSTREAMREQUEST
DESCRIPTOR.message_types_by_name['InitAudioStreamResponse'] = _INITAUDIOSTREAMRESPONSE
DESCRIPTOR.message_types_by_name['StreamAudioRequest'] = _STREAMAUDIOREQUEST
DESCRIPTOR.message_types_by_name['StreamAudioResponse'] = _STREAMAUDIORESPONSE
DESCRIPTOR.message_types_by_name['EndAudioStreamRequest'] = _ENDAUDIOSTREAMREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InitAudioStreamRequest = _reflection.GeneratedProtocolMessageType('InitAudioStreamRequest', (_message.Message,), dict(
  DESCRIPTOR = _INITAUDIOSTREAMREQUEST,
  __module__ = 'cogneed_protos.cogneed_ks.services.stream_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.InitAudioStreamRequest)
  ))
_sym_db.RegisterMessage(InitAudioStreamRequest)

InitAudioStreamResponse = _reflection.GeneratedProtocolMessageType('InitAudioStreamResponse', (_message.Message,), dict(
  DESCRIPTOR = _INITAUDIOSTREAMRESPONSE,
  __module__ = 'cogneed_protos.cogneed_ks.services.stream_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.InitAudioStreamResponse)
  ))
_sym_db.RegisterMessage(InitAudioStreamResponse)

StreamAudioRequest = _reflection.GeneratedProtocolMessageType('StreamAudioRequest', (_message.Message,), dict(
  DESCRIPTOR = _STREAMAUDIOREQUEST,
  __module__ = 'cogneed_protos.cogneed_ks.services.stream_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.StreamAudioRequest)
  ))
_sym_db.RegisterMessage(StreamAudioRequest)

StreamAudioResponse = _reflection.GeneratedProtocolMessageType('StreamAudioResponse', (_message.Message,), dict(
  DESCRIPTOR = _STREAMAUDIORESPONSE,
  __module__ = 'cogneed_protos.cogneed_ks.services.stream_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.StreamAudioResponse)
  ))
_sym_db.RegisterMessage(StreamAudioResponse)

EndAudioStreamRequest = _reflection.GeneratedProtocolMessageType('EndAudioStreamRequest', (_message.Message,), dict(
  DESCRIPTOR = _ENDAUDIOSTREAMREQUEST,
  __module__ = 'cogneed_protos.cogneed_ks.services.stream_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.EndAudioStreamRequest)
  ))
_sym_db.RegisterMessage(EndAudioStreamRequest)


DESCRIPTOR._options = None

_STREAMAUDIOSERVICE = _descriptor.ServiceDescriptor(
  name='StreamAudioService',
  full_name='ai.cogneed.cloud.speech.v1.StreamAudioService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=334,
  serialized_end=686,
  methods=[
  _descriptor.MethodDescriptor(
    name='init',
    full_name='ai.cogneed.cloud.speech.v1.StreamAudioService.init',
    index=0,
    containing_service=None,
    input_type=_INITAUDIOSTREAMREQUEST,
    output_type=_INITAUDIOSTREAMRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='stream',
    full_name='ai.cogneed.cloud.speech.v1.StreamAudioService.stream',
    index=1,
    containing_service=None,
    input_type=_STREAMAUDIOREQUEST,
    output_type=_STREAMAUDIORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='finalize',
    full_name='ai.cogneed.cloud.speech.v1.StreamAudioService.finalize',
    index=2,
    containing_service=None,
    input_type=_ENDAUDIOSTREAMREQUEST,
    output_type=_STREAMAUDIORESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_STREAMAUDIOSERVICE)

DESCRIPTOR.services_by_name['StreamAudioService'] = _STREAMAUDIOSERVICE

# @@protoc_insertion_point(module_scope)
