# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/cogneed-ks/services/mfcc.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.cogneed_ks.models import mfcc_audio_pb2 as cogneed__protos_dot_cogneed__ks_dot_models_dot_mfcc__audio__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/cogneed-ks/services/mfcc.proto',
  package='ai.cogneed.cloud.speech.v1',
  syntax='proto3',
  serialized_options=_b('\n\032ai.cogneed.cloud.speech.v1P\001'),
  serialized_pb=_b('\n-cogneed-protos/cogneed-ks/services/mfcc.proto\x12\x1a\x61i.cogneed.cloud.speech.v1\x1a\x31\x63ogneed-protos/cogneed-ks/models/mfcc_audio.proto\"#\n\x0bMfccRequest\x12\x14\n\x0cwave_content\x18\x01 \x01(\x0c\x32h\n\x0bMfccService\x12Y\n\x07\x63ompute\x12\'.ai.cogneed.cloud.speech.v1.MfccRequest\x1a%.ai.cogneed.cloud.speech.v1.MfccAudioB\x1e\n\x1a\x61i.cogneed.cloud.speech.v1P\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_cogneed__ks_dot_models_dot_mfcc__audio__pb2.DESCRIPTOR,])




_MFCCREQUEST = _descriptor.Descriptor(
  name='MfccRequest',
  full_name='ai.cogneed.cloud.speech.v1.MfccRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='wave_content', full_name='ai.cogneed.cloud.speech.v1.MfccRequest.wave_content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=128,
  serialized_end=163,
)

DESCRIPTOR.message_types_by_name['MfccRequest'] = _MFCCREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MfccRequest = _reflection.GeneratedProtocolMessageType('MfccRequest', (_message.Message,), dict(
  DESCRIPTOR = _MFCCREQUEST,
  __module__ = 'cogneed_protos.cogneed_ks.services.mfcc_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.MfccRequest)
  ))
_sym_db.RegisterMessage(MfccRequest)


DESCRIPTOR._options = None

_MFCCSERVICE = _descriptor.ServiceDescriptor(
  name='MfccService',
  full_name='ai.cogneed.cloud.speech.v1.MfccService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=165,
  serialized_end=269,
  methods=[
  _descriptor.MethodDescriptor(
    name='compute',
    full_name='ai.cogneed.cloud.speech.v1.MfccService.compute',
    index=0,
    containing_service=None,
    input_type=_MFCCREQUEST,
    output_type=cogneed__protos_dot_cogneed__ks_dot_models_dot_mfcc__audio__pb2._MFCCAUDIO,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_MFCCSERVICE)

DESCRIPTOR.services_by_name['MfccService'] = _MFCCSERVICE

# @@protoc_insertion_point(module_scope)
