# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.cogneed_ks.services import predict_pb2 as cogneed__protos_dot_cogneed__ks_dot_services_dot_predict__pb2


class PredictServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.predict = channel.unary_unary(
        '/ai.cogneed.cloud.speech.v1.PredictService/predict',
        request_serializer=cogneed__protos_dot_cogneed__ks_dot_services_dot_predict__pb2.PredictionRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_cogneed__ks_dot_services_dot_predict__pb2.PredictionResponse.FromString,
        )


class PredictServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def predict(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_PredictServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'predict': grpc.unary_unary_rpc_method_handler(
          servicer.predict,
          request_deserializer=cogneed__protos_dot_cogneed__ks_dot_services_dot_predict__pb2.PredictionRequest.FromString,
          response_serializer=cogneed__protos_dot_cogneed__ks_dot_services_dot_predict__pb2.PredictionResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.cloud.speech.v1.PredictService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
