# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/cogneed-ks/services/forward_audio.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/cogneed-ks/services/forward_audio.proto',
  package='ai.cogneed.cloud.speech.v1',
  syntax='proto3',
  serialized_options=_b('\n\032ai.cogneed.cloud.speech.v1P\001'),
  serialized_pb=_b('\n6cogneed-protos/cogneed-ks/services/forward_audio.proto\x12\x1a\x61i.cogneed.cloud.speech.v1\"Q\n\x13\x46orwardAudioRequest\x12\x11\n\tcaller_id\x18\x01 \x01(\t\x12\x16\n\x0e\x63\x61ller_id_name\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\x0c\"*\n\x14\x46orwardAudioResponse\x12\x12\n\nerror_code\x18\x01 \x01(\x01\x32\x87\x01\n\x13\x46orwardAudioService\x12p\n\x07\x63ollect\x12/.ai.cogneed.cloud.speech.v1.ForwardAudioRequest\x1a\x30.ai.cogneed.cloud.speech.v1.ForwardAudioResponse(\x01\x30\x01\x42\x1e\n\x1a\x61i.cogneed.cloud.speech.v1P\x01\x62\x06proto3')
)




_FORWARDAUDIOREQUEST = _descriptor.Descriptor(
  name='ForwardAudioRequest',
  full_name='ai.cogneed.cloud.speech.v1.ForwardAudioRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='caller_id', full_name='ai.cogneed.cloud.speech.v1.ForwardAudioRequest.caller_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='caller_id_name', full_name='ai.cogneed.cloud.speech.v1.ForwardAudioRequest.caller_id_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.cloud.speech.v1.ForwardAudioRequest.content', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=167,
)


_FORWARDAUDIORESPONSE = _descriptor.Descriptor(
  name='ForwardAudioResponse',
  full_name='ai.cogneed.cloud.speech.v1.ForwardAudioResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error_code', full_name='ai.cogneed.cloud.speech.v1.ForwardAudioResponse.error_code', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=211,
)

DESCRIPTOR.message_types_by_name['ForwardAudioRequest'] = _FORWARDAUDIOREQUEST
DESCRIPTOR.message_types_by_name['ForwardAudioResponse'] = _FORWARDAUDIORESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ForwardAudioRequest = _reflection.GeneratedProtocolMessageType('ForwardAudioRequest', (_message.Message,), dict(
  DESCRIPTOR = _FORWARDAUDIOREQUEST,
  __module__ = 'cogneed_protos.cogneed_ks.services.forward_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.ForwardAudioRequest)
  ))
_sym_db.RegisterMessage(ForwardAudioRequest)

ForwardAudioResponse = _reflection.GeneratedProtocolMessageType('ForwardAudioResponse', (_message.Message,), dict(
  DESCRIPTOR = _FORWARDAUDIORESPONSE,
  __module__ = 'cogneed_protos.cogneed_ks.services.forward_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.ForwardAudioResponse)
  ))
_sym_db.RegisterMessage(ForwardAudioResponse)


DESCRIPTOR._options = None

_FORWARDAUDIOSERVICE = _descriptor.ServiceDescriptor(
  name='ForwardAudioService',
  full_name='ai.cogneed.cloud.speech.v1.ForwardAudioService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=214,
  serialized_end=349,
  methods=[
  _descriptor.MethodDescriptor(
    name='collect',
    full_name='ai.cogneed.cloud.speech.v1.ForwardAudioService.collect',
    index=0,
    containing_service=None,
    input_type=_FORWARDAUDIOREQUEST,
    output_type=_FORWARDAUDIORESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_FORWARDAUDIOSERVICE)

DESCRIPTOR.services_by_name['ForwardAudioService'] = _FORWARDAUDIOSERVICE

# @@protoc_insertion_point(module_scope)
