# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/cogneed-ks/services/audio_prediction.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/cogneed-ks/services/audio_prediction.proto',
  package='ai.cogneed.cloud.speech.v1',
  syntax='proto3',
  serialized_options=_b('\n\032ai.cogneed.cloud.speech.v1P\001'),
  serialized_pb=_b('\n9cogneed-protos/cogneed-ks/services/audio_prediction.proto\x12\x1a\x61i.cogneed.cloud.speech.v1\"_\n\x17\x41udioPredictionResponse\x12\x10\n\x08start_ms\x18\x01 \x01(\x03\x12\x0e\n\x06\x65nd_ms\x18\x02 \x01(\x03\x12\x13\n\x0bprobability\x18\x03 \x01(\x01\x12\r\n\x05label\x18\x04 \x01(\t\"g\n\x16\x41udioPredictionRequest\x12\x11\n\tcall_uuid\x18\x01 \x01(\t\x12\x15\n\rmodel_version\x18\x02 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\x0c\x12\x12\n\nblob_index\x18\x04 \x01(\x03\x32\x90\x01\n\x16\x41udioPredictionService\x12v\n\x07predict\x12\x32.ai.cogneed.cloud.speech.v1.AudioPredictionRequest\x1a\x33.ai.cogneed.cloud.speech.v1.AudioPredictionResponse(\x01\x30\x01\x42\x1e\n\x1a\x61i.cogneed.cloud.speech.v1P\x01\x62\x06proto3')
)




_AUDIOPREDICTIONRESPONSE = _descriptor.Descriptor(
  name='AudioPredictionResponse',
  full_name='ai.cogneed.cloud.speech.v1.AudioPredictionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_ms', full_name='ai.cogneed.cloud.speech.v1.AudioPredictionResponse.start_ms', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_ms', full_name='ai.cogneed.cloud.speech.v1.AudioPredictionResponse.end_ms', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='probability', full_name='ai.cogneed.cloud.speech.v1.AudioPredictionResponse.probability', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='ai.cogneed.cloud.speech.v1.AudioPredictionResponse.label', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=184,
)


_AUDIOPREDICTIONREQUEST = _descriptor.Descriptor(
  name='AudioPredictionRequest',
  full_name='ai.cogneed.cloud.speech.v1.AudioPredictionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_uuid', full_name='ai.cogneed.cloud.speech.v1.AudioPredictionRequest.call_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_version', full_name='ai.cogneed.cloud.speech.v1.AudioPredictionRequest.model_version', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.cloud.speech.v1.AudioPredictionRequest.content', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blob_index', full_name='ai.cogneed.cloud.speech.v1.AudioPredictionRequest.blob_index', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=186,
  serialized_end=289,
)

DESCRIPTOR.message_types_by_name['AudioPredictionResponse'] = _AUDIOPREDICTIONRESPONSE
DESCRIPTOR.message_types_by_name['AudioPredictionRequest'] = _AUDIOPREDICTIONREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AudioPredictionResponse = _reflection.GeneratedProtocolMessageType('AudioPredictionResponse', (_message.Message,), dict(
  DESCRIPTOR = _AUDIOPREDICTIONRESPONSE,
  __module__ = 'cogneed_protos.cogneed_ks.services.audio_prediction_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.AudioPredictionResponse)
  ))
_sym_db.RegisterMessage(AudioPredictionResponse)

AudioPredictionRequest = _reflection.GeneratedProtocolMessageType('AudioPredictionRequest', (_message.Message,), dict(
  DESCRIPTOR = _AUDIOPREDICTIONREQUEST,
  __module__ = 'cogneed_protos.cogneed_ks.services.audio_prediction_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.AudioPredictionRequest)
  ))
_sym_db.RegisterMessage(AudioPredictionRequest)


DESCRIPTOR._options = None

_AUDIOPREDICTIONSERVICE = _descriptor.ServiceDescriptor(
  name='AudioPredictionService',
  full_name='ai.cogneed.cloud.speech.v1.AudioPredictionService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=292,
  serialized_end=436,
  methods=[
  _descriptor.MethodDescriptor(
    name='predict',
    full_name='ai.cogneed.cloud.speech.v1.AudioPredictionService.predict',
    index=0,
    containing_service=None,
    input_type=_AUDIOPREDICTIONREQUEST,
    output_type=_AUDIOPREDICTIONRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_AUDIOPREDICTIONSERVICE)

DESCRIPTOR.services_by_name['AudioPredictionService'] = _AUDIOPREDICTIONSERVICE

# @@protoc_insertion_point(module_scope)
